SupportsReturningClause

Trait SupportsReturningClause 

pub trait SupportsReturningClause { }
Available on crate feature i-implement-a-third-party-backend-and-opt-into-breaking-changes only.
A marker trait indicating if a RETURNING clause is supported or not

If you use a custom type to specify specialized support for RETURNING clauses implementing this trait opts in supporting RETURNING clause syntax

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors